function result = Mie_rain2a(fGHz, R, TK, dD, Dmax, distribution)

% Dual plot of weighting functions of 
% Rain extinction, scattering, absorption, backscattering and 
% asymmetric scattering coefficient in 1/km/mm versus drop diameter
% for different drop-size distributions (Sauvageot et al. 1992),
% using Mie Theory, and dielectric model of Liebe et al. 1991.
% Input:
% fGHz: frequency in GHz, 
% R: rain rate in mm/h, TK: Temp. in K, incremental diameter dD in mm, 
% Dmax: maximum diameter in mm
% distribution='LP' for Laws-Parsons, 'MP' for Marshall-Palmer,
% 'JD' for Joss-Drizzle, or 'JT' for Joss-Thunderstorm
% C. Mtzler, Nov. 2002.

nsteps=round(Dmax/dD);
m=sqrt(epswater(fGHz, TK));
nx=(1:nsteps)';
D=nx*dD;
if distribution=='MP'
    NP=rainMP(R,D);
elseif distribution=='LP'
    NP=rainLP(R,D);
elseif distribution=='JD'
    NP=rainJD(R,D);
elseif distribution=='JT'
    NP=rainJT(R,D);
end;
c0=299.793;
x=pi*D*fGHz/c0;
sigmag=pi*D.*D/4;
sn=sigmag.*NP*1000000;
for j = 1:nsteps
    a(j,:)=Mie(m,x(j));
end;
b(:,1)=D;
b(:,2)=a(:,1).*sn;
b(:,4)=a(:,2).*sn;
b(:,3)=a(:,3).*sn;
b(:,5)=a(:,4).*sn;
b(:,6)=a(:,2).*a(:,5).*sn;

% plotting the results
m1=real(m);m2=imag(m);d=distribution
subplot(1,2,1)
plot(b(:,1),b(:,2:3))
legend('dGext/dD','dGabs/dD')
title(sprintf('%gGHz, %gK, %gmm/h, %s',fGHz,TK,R,d))
xlabel('D (mm)');ylabel('dGi/dD (1/km/mm)')
subplot(1,2,2)
plot(b(:,1),b(:,4:6))
legend('dGsca/dD','dGb/dD','dGasy/dD')
title(sprintf('%gGHz, %gK, %gmm/h, %s',fGHz,TK,R,d))
xlabel('D (mm)');ylabel('dGi/dD (1/km/mm)')

gext= sum(b(:,2))*dD;
gsca= sum(b(:,3))*dD;
gabs= sum(b(:,4))*dD;
gb=   sum(b(:,5))*dD;
gteta=sum(b(:,6))*dD;

result=[gext gsca gabs gb gteta];