function result = Mie_rain3d(fGHz, TK, nrain, dD, nsteps)

% Cosine of effective scattering angle versus rain rate, R,
% using Mie Theory, and Liebe '91 dielectric model for water.
% for 4 different size distribution functions:
% Laws-Parsons, Marshall-Palmer, Joss-Drizzle, Joss-Thunderstorm
% Input:
% fGHz: frequency in GHz, TK: temperature in K, 
% nrain: Number of rain rates between Rmin=0.1 and Rmax=100mm/h
% dD, nsteps: diameter step size and number of steps
% C. Mtzler, June 2002, revised Nov. 2002.

Rmin=0.1;   
m=sqrt(epswater(fGHz, TK));
fact=1000^(1/(nrain-0.99999));
R=Rmin/fact;
Dmax=dD*nsteps;
D=(dD:dD:Dmax)';
c0=299.793;
x=pi*D*fGHz/c0;
sigmag=pi*D.*D/4;
for j = 1:nsteps    
    a(j,:)=Mie(m,x(j));
end;
for jr = 1:nrain
    R=R*fact;
    NP1=rainLP(R,D);
    NP2=rainMP(R,D);
    NP3=rainJD(R,D);
    NP4=rainJT(R,D);
    sn1=sigmag.*NP1*1000000;
    sn2=sigmag.*NP2*1000000;
    sn3=sigmag.*NP3*1000000;
    sn4=sigmag.*NP4*1000000;
    b(:,1)=D;
    b(:,2)=a(:,1).*sn1;
    b(:,3)=a(:,2).*sn1;
    b(:,4)=a(:,3).*sn1;
    b(:,5)=a(:,4).*sn1;
    b(:,6)=a(:,2).*a(:,5).*sn1; 
    gext= sum(b(:,2))*dD;
    gsca= sum(b(:,3))*dD;
    gabs= sum(b(:,4))*dD;
    gb=   sum(b(:,5))*dD;
    gteta=sum(b(:,6))*dD/gsca;
    b1(:,2)=a(:,1).*sn2;
    b1(:,3)=a(:,2).*sn2;
    b1(:,4)=a(:,3).*sn2;
    b1(:,5)=a(:,4).*sn2;
    b1(:,6)=a(:,2).*a(:,5).*sn2; 
    gext1= sum(b1(:,2))*dD;
    gsca1= sum(b1(:,3))*dD;
    gabs1= sum(b1(:,4))*dD;
    gb1=   sum(b1(:,5))*dD;
    gteta1=sum(b1(:,6))*dD/gsca1;
    b2(:,2)=a(:,1).*sn3;
    b2(:,3)=a(:,2).*sn3;
    b2(:,4)=a(:,3).*sn3;
    b2(:,5)=a(:,4).*sn3;
    b2(:,6)=a(:,2).*a(:,5).*sn3; 
    gext2= sum(b2(:,2))*dD;
    gsca2= sum(b2(:,3))*dD;
    gabs2= sum(b2(:,4))*dD;
    gb2=   sum(b2(:,5))*dD;
    gteta2=sum(b2(:,6))*dD/gsca2;
    b3(:,2)=a(:,1).*sn4;
    b3(:,3)=a(:,2).*sn4;
    b3(:,4)=a(:,3).*sn4;
    b3(:,5)=a(:,4).*sn4;
    b3(:,6)=a(:,2).*a(:,5).*sn4; 
    gext3= sum(b3(:,2))*dD;
    gsca3= sum(b3(:,3))*dD;
    gabs3= sum(b3(:,4))*dD;
    gb3=   sum(b3(:,5))*dD;
    gteta3=sum(b3(:,6))*dD/gsca3;
    re(jr,:)=[R gext gext1 gext2 gext3];
    rs(jr,:)=[R gsca gsca1 gsca2 gsca3];
    rb(jr,:)=[R gb gb1 gb2 gb3];
    ra(jr,:)=[R gabs gabs1 gabs2 gabs3];
    rt(jr,:)=[R gteta gteta1 gteta2 gteta3];    
end;
r1=re(:,1); r2=re(:,2); r3=re(:,3); r4=re(:,4); r5=re(:,5); 
            r6=ra(:,2); r7=ra(:,3); r8=ra(:,4); r9=ra(:,5); 
            r10=rb(:,2);r11=rb(:,3);r12=rb(:,4);r13=rb(:,5); 
            r14=rs(:,2);r15=rs(:,3);r16=rs(:,4);r17=rs(:,5);
            r18=rt(:,2);r19=rt(:,3);r20=rt(:,4);r21=rt(:,5);
semilogx(r1, r18,'r.-',r1, r19','k-',r1, r20,'b-',r1, r21,'g-')
legend('LP','MP','JD','JT')
title(sprintf('<Cos(teta)> at f=%gGHz, T=%gK',fGHz,TK'))
xlabel('R (mm/h)');    
result=[r1,r18,r19,r20,r21];
